Crate ic_auth_types

Structs

ByteArrayB64
Wrapper around [u8; N] to serialize and deserialize efficiently. If the serialization format is human readable (formats like JSON and YAML), it will be encoded in Base64URL. Otherwise, it will be serialized as a byte array.
ByteBufB64
Wrapper around Vec<u8> to serialize and deserialize efficiently. If the serialization format is human readable (formats like JSON and YAML), it will be encoded in Base64URL. Otherwise, it will be serialized as a byte array.
Delegation
A delegation from one key to another.
DelegationCompact
DelegationCompact is a compact representation of a Delegation. It is used to reduce the size of the delegation when it is serialized.
SignInResponse
SignedDelegation
SignedDelegation is a Delegation that has been signed by an Identity.
SignedDelegationCompact
SignedDelegationCompact is a compact representation of a SignedDelegation. It is used to reduce the size of the delegation when it is serialized.
Xid
Represents a unique identifier with 12 bytes. Based on the xid. See: https://github.com/rs/xid

Constants

EMPTY_XID
A constant representing an empty XID (all zeros)
RAW_LEN
Length of the raw XID byte array