Wrapper around [u8; N] to serialize and deserialize efficiently.
If the serialization format is human readable (formats like JSON and YAML), it will be encoded in Base64URL.
Otherwise, it will be serialized as a byte array.
Wrapper around Vec<u8> to serialize and deserialize efficiently.
If the serialization format is human readable (formats like JSON and YAML), it will be encoded in Base64URL.
Otherwise, it will be serialized as a byte array.